  XS(XS_Bio__Emboss_ajAcdDebug); /* prototype */
  XS(XS_Bio__Emboss_ajAcdDebugIsSet); /* prototype */
  XS(XS_Bio__Emboss_ajAcdExit); /* prototype */
  XS(XS_Bio__Emboss_ajAcdFilter); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetAlign); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetArray); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetBool); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetCodon); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDatafile); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetDirlist); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetFeat); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetFeatout); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetFilelist); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetFloat); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetGraph); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetGraphxy); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetInfile); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetInt); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetList); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetListI); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetMatrix); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetMatrixf); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetOutfile); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajAcdGetCpdb); /* prototype */
#else
  XS(XS_Bio__Emboss_ajAcdGetCpdb); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajAcdGetRange); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetRegexp); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetReport); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajAcdGetScop); /* prototype */
#else
  XS(XS_Bio__Emboss_ajAcdGetScop); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajAcdGetSelect); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSelectI); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeq); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqall); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqout); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqoutall); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqoutset); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetSeqset); /* prototype */
  XS(XS_Bio__Emboss_ajAcdGetString); /* prototype */
  XS(XS_Bio__Emboss_ajAcdPrintType); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajAcdProgram); /* prototype */
#else
  XS(XS_Bio__Emboss_ajAcdProgram); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajAcdProgramS); /* prototype */
  XS(XS_Bio__Emboss_ajAcdStdout); /* prototype */
  XS(XS_Bio__Emboss_ajAcdValue); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsChild); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsCompMult); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajFeatCopy); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableCopy); /* prototype */
  XS(XS_Bio__Emboss_ajFeatUfoRead); /* prototype */
#else
  XS(XS_Bio__Emboss_ajFeatCopy); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableCopy); /* prototype */
  XS(XS_Bio__Emboss_ajFeatUfoRead); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajFeatDel); /* prototype */
  XS(XS_Bio__Emboss_ajFeatExit); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetEnd); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetForward); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetFrame); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetLocs); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetNote); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetNoteI); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetStart); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetTag); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetType); /* prototype */
  XS(XS_Bio__Emboss_ajFeatGetTrans); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsLocal); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsLocalRange); /* prototype */
  XS(XS_Bio__Emboss_ajFeatIsMultiple); /* prototype */
  XS(XS_Bio__Emboss_ajFeatLocToSeq); /* prototype */
  XS(XS_Bio__Emboss_ajFeatNew); /* prototype */
  XS(XS_Bio__Emboss_ajFeatNewII); /* prototype */
  XS(XS_Bio__Emboss_ajFeatNewProt); /* prototype */
  XS(XS_Bio__Emboss_ajFeatRead); /* prototype */
#ifdef HAVE_EMBOSS_2_7_0
  XS(XS_Bio__Emboss_ajFeatReverse); /* prototype */
#else
  XS(XS_Bio__Emboss_ajFeatReverse); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajFeatSetDesc); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSetDescApp); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSortByEnd); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSortByStart); /* prototype */
  XS(XS_Bio__Emboss_ajFeatSortByType); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableAdd); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableBegin); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableClear); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableDel); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableEnd); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableGetName); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableIsNuc); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableIsProt); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableLen); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableNew); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableNewDna); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableNewProt); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableNewSeq); /* prototype */
  XS(XS_Bio__Emboss_ajFeattablePos); /* prototype */
  XS(XS_Bio__Emboss_ajFeattablePosI); /* prototype */
  XS(XS_Bio__Emboss_ajFeattablePosII); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableReverse); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableSetDna); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableSetProt); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableSize); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableTrace); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteDdbj); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteEmbl); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteGenbank); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteGff); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWritePir); /* prototype */
  XS(XS_Bio__Emboss_ajFeattableWriteSwiss); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInClear); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInDel); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInNew); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInNewSS); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabInNewSSF); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutDel); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutFile); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutFilename); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutIsOpen); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutNew); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutNewSSF); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutOpen); /* prototype */
  XS(XS_Bio__Emboss_ajFeattabOutSet); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagAdd); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagAddC); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagAddCC); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagIter); /* prototype */
#ifdef HAVE_EMBOSS_2_7_0
  XS(XS_Bio__Emboss_ajFeatTagSet); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagSetC); /* prototype */
#else
  XS(XS_Bio__Emboss_ajFeatTagSet); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagSetC); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajFeatTagTrace); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTagval); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTest); /* prototype */
  XS(XS_Bio__Emboss_ajFeatTrace); /* prototype */
  XS(XS_Bio__Emboss_ajFeatUfoWrite); /* prototype */
  XS(XS_Bio__Emboss_ajFeatWrite); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffClear); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffDel); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffEmpty); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffEnd); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffEof); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffFile); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffFix); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffFp); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffFreeClear); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffGet); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffGetL); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffGetStore); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffLoad); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffLoadC); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffLoadS); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNew); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewDC); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewDF); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewDW); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewFile); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewIn); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewInList); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNewS); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffNobuff); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffReset); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffResetPos); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffSetFile); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffSize); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffStripHtml); /* prototype */
#ifndef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajFileBuffStripSrs); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajFileBuffTrace); /* prototype */
  XS(XS_Bio__Emboss_ajFileBuffTraceFull); /* prototype */
  XS(XS_Bio__Emboss_ajFileClose); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataDirNew); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataDirNewC); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataNew); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataNewC); /* prototype */
  XS(XS_Bio__Emboss_ajFileDataNewWrite); /* prototype */
  XS(XS_Bio__Emboss_ajFileDir); /* prototype */
  XS(XS_Bio__Emboss_ajFileDirFix); /* prototype */
  XS(XS_Bio__Emboss_ajFileDirUp); /* prototype */
  XS(XS_Bio__Emboss_ajFileDirPath); /* prototype */
  XS(XS_Bio__Emboss_ajFileDirTrim); /* prototype */
  XS(XS_Bio__Emboss_ajFileExit); /* prototype */
  XS(XS_Bio__Emboss_ajFileFileList); /* prototype */
  XS(XS_Bio__Emboss_ajFileFp); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetwd); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetName); /* prototype */
  XS(XS_Bio__Emboss_ajFileGets); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetsL); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetsTrim); /* prototype */
  XS(XS_Bio__Emboss_ajFileGetsTrimL); /* prototype */
  XS(XS_Bio__Emboss_ajFileLength); /* prototype */
  XS(XS_Bio__Emboss_ajFileName); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameDirSet); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameDirSetC); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameExt); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameExtC); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameShorten); /* prototype */
  XS(XS_Bio__Emboss_ajFileNameTrim); /* prototype */
  XS(XS_Bio__Emboss_ajFileNew); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewApp); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewDC); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewDF); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewDW); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewF); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewIn); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewInC); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewInPipe); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewInList); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewOut); /* prototype */
  XS(XS_Bio__Emboss_ajFileNewOutD); /* prototype */
  XS(XS_Bio__Emboss_ajFileOutHeader); /* prototype */
  XS(XS_Bio__Emboss_ajFileOutClose); /* prototype */
  XS(XS_Bio__Emboss_ajFileNext); /* prototype */
  XS(XS_Bio__Emboss_ajFileRead); /* prototype */
  XS(XS_Bio__Emboss_ajFileReopen); /* prototype */
  XS(XS_Bio__Emboss_ajFileReadLine); /* prototype */
  XS(XS_Bio__Emboss_ajFileReadUint); /* prototype */
  XS(XS_Bio__Emboss_ajFileScan); /* prototype */
  XS(XS_Bio__Emboss_ajFileSeek); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajFileStat); /* prototype */
#else
  XS(XS_Bio__Emboss_ajFileStat); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajFileStderr); /* prototype */
  XS(XS_Bio__Emboss_ajFileStdin); /* prototype */
  XS(XS_Bio__Emboss_ajFileStdout); /* prototype */
  XS(XS_Bio__Emboss_ajFileTell); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajFileTempName); /* prototype */
#else
  XS(XS_Bio__Emboss_ajFileTempName); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajFileTestSkip); /* prototype */
  XS(XS_Bio__Emboss_ajFileTrace); /* prototype */
  XS(XS_Bio__Emboss_ajFileUnbuffer); /* prototype */
  XS(XS_Bio__Emboss_ajFileWrite); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteByte); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteChar); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteInt2); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteInt4); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteInt8); /* prototype */
  XS(XS_Bio__Emboss_ajFileWriteStr); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
#else
#endif
  XS(XS_Bio__Emboss_ajHistClose); /* prototype */
  XS(XS_Bio__Emboss_ajHistCopyData); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajHistDelete); /* prototype */
#else
  XS(XS_Bio__Emboss_ajHistDelete); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajHistDisplay); /* prototype */
  XS(XS_Bio__Emboss_ajHistNew); /* prototype */
  XS(XS_Bio__Emboss_ajHistNewG); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetBlackandWhite); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetColour); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiTitle); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiXTitle); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiXTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiYTitle); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetMultiYTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetPattern); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetPtrToData); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetXAxisC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetYAxisLeftC); /* prototype */
  XS(XS_Bio__Emboss_ajHistSetYAxisRightC); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajListAppend); /* prototype */
  XS(XS_Bio__Emboss_ajListIterFree); /* prototype */
#else
  XS(XS_Bio__Emboss_ajListAppend); /* prototype */
  XS(XS_Bio__Emboss_ajListIterFree); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajListCopy); /* prototype */
  XS(XS_Bio__Emboss_ajListDel); /* prototype */
  XS(XS_Bio__Emboss_ajListFree); /* prototype */
  XS(XS_Bio__Emboss_ajListInsert); /* prototype */
  XS(XS_Bio__Emboss_ajListIter); /* prototype */
  XS(XS_Bio__Emboss_ajListIterBack); /* prototype */
  XS(XS_Bio__Emboss_ajListIterBackDone); /* prototype */
  XS(XS_Bio__Emboss_ajListIterBackMore); /* prototype */
  XS(XS_Bio__Emboss_ajListIterBackNext); /* prototype */
  XS(XS_Bio__Emboss_ajListIterNext); /* prototype */
  XS(XS_Bio__Emboss_ajListIterMore); /* prototype */
  XS(XS_Bio__Emboss_ajListIterDone); /* prototype */
  XS(XS_Bio__Emboss_ajListIterTrace); /* prototype */
  XS(XS_Bio__Emboss_ajListLength); /* prototype */
  XS(XS_Bio__Emboss_ajListNew); /* prototype */
  XS(XS_Bio__Emboss_ajListPush); /* prototype */
  XS(XS_Bio__Emboss_ajListPushApp); /* prototype */
  XS(XS_Bio__Emboss_ajListReverse); /* prototype */
  XS(XS_Bio__Emboss_ajListstrCopy); /* prototype */
  XS(XS_Bio__Emboss_ajListstrDel); /* prototype */
  XS(XS_Bio__Emboss_ajListstrFree); /* prototype */
  XS(XS_Bio__Emboss_ajListstrIterTrace); /* prototype */
  XS(XS_Bio__Emboss_ajListstrLength); /* prototype */
  XS(XS_Bio__Emboss_ajListstrNew); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPop); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPopEnd); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPush); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPushApp); /* prototype */
  XS(XS_Bio__Emboss_ajListstrReverse); /* prototype */
  XS(XS_Bio__Emboss_ajListstrToArray); /* prototype */
  XS(XS_Bio__Emboss_ajListstrTrace); /* prototype */
  XS(XS_Bio__Emboss_ajListTrace); /* prototype */
  XS(XS_Bio__Emboss_ajListPushList); /* prototype */
  XS(XS_Bio__Emboss_ajListstrPushList); /* prototype */
  XS(XS_Bio__Emboss_ajListRemove); /* prototype */
  XS(XS_Bio__Emboss_ajListstrClone); /* prototype */
  XS(XS_Bio__Emboss_ajListstrInsert); /* prototype */
  XS(XS_Bio__Emboss_ajListstrRemove); /* prototype */
  XS(XS_Bio__Emboss_ajListSort); /* prototype */
  XS(XS_Bio__Emboss_ajDegToRad); /* prototype */
  XS(XS_Bio__Emboss_ajGaussProb); /* prototype */
  XS(XS_Bio__Emboss_ajGeoMean); /* prototype */
  XS(XS_Bio__Emboss_ajPolToRec); /* prototype */
  XS(XS_Bio__Emboss_ajPosMod); /* prototype */
  XS(XS_Bio__Emboss_ajRadToDeg); /* prototype */
  XS(XS_Bio__Emboss_ajRandomNumber); /* prototype */
  XS(XS_Bio__Emboss_ajRandomNumberD); /* prototype */
  XS(XS_Bio__Emboss_ajRandomSeed); /* prototype */
  XS(XS_Bio__Emboss_ajRecToPol); /* prototype */
  XS(XS_Bio__Emboss_ajRound); /* prototype */
  XS(XS_Bio__Emboss_ajRoundF); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajMemAlloc); /* prototype */
  XS(XS_Bio__Emboss_ajMemCalloc); /* prototype */
  XS(XS_Bio__Emboss_ajMemCalloc0); /* prototype */
  XS(XS_Bio__Emboss_ajMemResize); /* prototype */
#else
  XS(XS_Bio__Emboss_ajMemAlloc); /* prototype */
  XS(XS_Bio__Emboss_ajMemCalloc); /* prototype */
  XS(XS_Bio__Emboss_ajMemCalloc0); /* prototype */
  XS(XS_Bio__Emboss_ajMemResize); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajMemFree); /* prototype */
  XS(XS_Bio__Emboss_ajMemStat); /* prototype */
  XS(XS_Bio__Emboss_ajMemExit); /* prototype */
  XS(XS_Bio__Emboss_ajNamDatabase); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbDetails); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbGetDbalias); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbGetUrl); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbData); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbQuery); /* prototype */
  XS(XS_Bio__Emboss_ajNamDbTest); /* prototype */
  XS(XS_Bio__Emboss_ajNamDebugOrigin); /* prototype */
  XS(XS_Bio__Emboss_ajNamDebugDatabases); /* prototype */
  XS(XS_Bio__Emboss_ajNamExit); /* prototype */
  XS(XS_Bio__Emboss_ajNamGetenv); /* prototype */
  XS(XS_Bio__Emboss_ajNamGetValue); /* prototype */
  XS(XS_Bio__Emboss_ajNamGetValueC); /* prototype */
  XS(XS_Bio__Emboss_ajNamInit); /* prototype */
  XS(XS_Bio__Emboss_ajNamListDatabases); /* prototype */
  XS(XS_Bio__Emboss_ajNamListListDatabases); /* prototype */
  XS(XS_Bio__Emboss_ajNamListOrigin); /* prototype */
  XS(XS_Bio__Emboss_ajNamPrintDbAttr); /* prototype */
  XS(XS_Bio__Emboss_ajNamResolve); /* prototype */
  XS(XS_Bio__Emboss_ajNamRoot); /* prototype */
  XS(XS_Bio__Emboss_ajNamRootBase); /* prototype */
  XS(XS_Bio__Emboss_ajNamRootInstall); /* prototype */
  XS(XS_Bio__Emboss_ajNamRootPack); /* prototype */
  XS(XS_Bio__Emboss_ajNamRootVersion); /* prototype */
  XS(XS_Bio__Emboss_ajRangeNewI); /* prototype */
  XS(XS_Bio__Emboss_ajRangeDefault); /* prototype */
  XS(XS_Bio__Emboss_ajRangeDel); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajRangeGet); /* prototype */
  XS(XS_Bio__Emboss_ajRangeFile); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrExtract); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrExtractList); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrStuff); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrMask); /* prototype */
#else
  XS(XS_Bio__Emboss_ajRangeGet); /* prototype */
  XS(XS_Bio__Emboss_ajRangeFile); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrExtractList); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrExtract); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrStuff); /* prototype */
  XS(XS_Bio__Emboss_ajRangeStrMask); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajRangeNumber); /* prototype */
  XS(XS_Bio__Emboss_ajRangeText); /* prototype */
  XS(XS_Bio__Emboss_ajRangeValues); /* prototype */
  XS(XS_Bio__Emboss_ajRangeChange); /* prototype */
  XS(XS_Bio__Emboss_ajRangeBegin); /* prototype */
  XS(XS_Bio__Emboss_ajRangeOverlapSingle); /* prototype */
  XS(XS_Bio__Emboss_ajRangeOverlaps); /* prototype */
  XS(XS_Bio__Emboss_ajRangeOrdered); /* prototype */
  XS(XS_Bio__Emboss_ajReportClose); /* prototype */
  XS(XS_Bio__Emboss_ajReportDel); /* prototype */
  XS(XS_Bio__Emboss_ajReportOpen); /* prototype */
  XS(XS_Bio__Emboss_ajReportFileAdd); /* prototype */
  XS(XS_Bio__Emboss_ajReportFindFormat); /* prototype */
  XS(XS_Bio__Emboss_ajReportFormatDefault); /* prototype */
  XS(XS_Bio__Emboss_ajReportNew); /* prototype */
  XS(XS_Bio__Emboss_ajReportPrintFormat); /* prototype */
  XS(XS_Bio__Emboss_ajReportSeqName); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetHeader); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetHeaderC); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetTags); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetTail); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetTailC); /* prototype */
  XS(XS_Bio__Emboss_ajReportSetType); /* prototype */
  XS(XS_Bio__Emboss_ajReportWriteTail); /* prototype */
  XS(XS_Bio__Emboss_ajReportValid); /* prototype */
  XS(XS_Bio__Emboss_ajReportWrite); /* prototype */
  XS(XS_Bio__Emboss_ajReportWriteHeader); /* prototype */
  XS(XS_Bio__Emboss_ajIsAccession); /* prototype */
  XS(XS_Bio__Emboss_ajIsSeqversion); /* prototype */
  XS(XS_Bio__Emboss_ajSelexNew); /* prototype */
  XS(XS_Bio__Emboss_ajSelexDel); /* prototype */
  XS(XS_Bio__Emboss_ajSelexdataNew); /* prototype */
  XS(XS_Bio__Emboss_ajSelexdataDel); /* prototype */
  XS(XS_Bio__Emboss_ajSelexSQDel); /* prototype */
  XS(XS_Bio__Emboss_ajSelexSQNew); /* prototype */
  XS(XS_Bio__Emboss_ajStockholmNew); /* prototype */
  XS(XS_Bio__Emboss_ajStockholmDel); /* prototype */
  XS(XS_Bio__Emboss_ajStockholmdataDel); /* prototype */
  XS(XS_Bio__Emboss_ajStockholmdataNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallBegin); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallEnd); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallGetName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallGetNameSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallGetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallGetUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallNext); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallReverse); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallToLower); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssAcc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssAccC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssDesc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssDescC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssEntry); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssEntryC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssFile); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssFull); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssFullC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssGi); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssGiC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssNameC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSeqC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSeqCI); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSv); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssSvC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssUfo); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssUfoC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAssUsaC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqBaseComp); /* prototype */
  XS(XS_Bio__Emboss_ajSeqBegin); /* prototype */
  XS(XS_Bio__Emboss_ajSeqChar); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCharCopy); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCharCopyL); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCheckGcg); /* prototype */
  XS(XS_Bio__Emboss_ajSeqClear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCompOnly); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCompOnlyStr); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCopyFeat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCount); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCrc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtK); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtNewText); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtNewZero); /* prototype */
  XS(XS_Bio__Emboss_ajSeqCvtTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqEnd); /* prototype */
  XS(XS_Bio__Emboss_ajSeqFill); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapCount); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapCountS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapStandard); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetAcc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetDesc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetEntry); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetFeat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetGi); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetReverse); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetSv); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqIsNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqIsProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqMakeUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqMod); /* prototype */
  XS(XS_Bio__Emboss_ajSeqMW); /* prototype */
  XS(XS_Bio__Emboss_ajSeqName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewL); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNewS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqNum); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOffend); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPos); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPosI); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPosII); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryClear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryIs); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryStarclear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqQueryWild); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReplace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReplaceC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReverse); /* prototype */
  XS(XS_Bio__Emboss_ajSeqReverseStr); /* prototype */
  XS(XS_Bio__Emboss_ajSeqRevOnly); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetBegin); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetEnd); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetFill); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetGetUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetIsDna); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetIsNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetIsProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetIsRna); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetReverse); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetSize); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetToLower); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetTotweight); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetWeight); /* prototype */
  XS(XS_Bio__Emboss_ajSeqStr); /* prototype */
  XS(XS_Bio__Emboss_ajSeqStrCopy); /* prototype */
  XS(XS_Bio__Emboss_ajSeqToLower); /* prototype */
  XS(XS_Bio__Emboss_ajSeqToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqFindOutFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqTrim); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetBaseOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetBasePosition); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetBasePosOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetBaseSpace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetData); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetFWO); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetNBase); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetNData); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetPrimerOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIGetPrimerPosition); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajSeqABIGetSignal); /* prototype */
#else
  XS(XS_Bio__Emboss_ajSeqABIGetSignal); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajSeqABIGetTraceOffset); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIMachineName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABIReadSeq); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABISampleName); /* prototype */
  XS(XS_Bio__Emboss_ajSeqABITest); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAccessAsis); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAccessFile); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAccessOffset); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajSeqMethod); /* prototype */
#else
  XS(XS_Bio__Emboss_ajSeqMethod); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajSeqPrintAccess); /* prototype */
  XS(XS_Bio__Emboss_ajSeqallFile); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAllRead); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGetFromUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinClear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqParseFasta); /* prototype */
  XS(XS_Bio__Emboss_ajSeqParseNcbi); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinSetNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinSetProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinSetRange); /* prototype */
  XS(XS_Bio__Emboss_ajSeqinUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPrintInFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqRead); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetApp); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetRead); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetFromList); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetFromPair); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGap); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapLen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqGapS); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPrintType); /* prototype */
  XS(XS_Bio__Emboss_ajSeqSetNuc); /* prototype */
  XS(XS_Bio__Emboss_ajSeqSetProt); /* prototype */
  XS(XS_Bio__Emboss_ajSeqType); /* prototype */
  XS(XS_Bio__Emboss_ajSeqAllWrite); /* prototype */
  XS(XS_Bio__Emboss_ajSeqFileNewOut); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutCheckGcg); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutClear); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutDel); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOutFormatDefault); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOutFormatSingle); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutNew); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutNewF); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutOpen); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOutSetFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqOutSetFormatC); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutTrace); /* prototype */
  XS(XS_Bio__Emboss_ajSeqPrintOutFormat); /* prototype */
  XS(XS_Bio__Emboss_ajSeqoutUsa); /* prototype */
  XS(XS_Bio__Emboss_ajSeqsetWrite); /* prototype */
  XS(XS_Bio__Emboss_ajSeqWrite); /* prototype */
  XS(XS_Bio__Emboss_ajSeqWriteClose); /* prototype */
  XS(XS_Bio__Emboss_ajSeqWriteXyz); /* prototype */
#ifdef HAVE_EMBOSS_2_6_0
  XS(XS_Bio__Emboss_ajSssWriteXyz); /* prototype */
#endif
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajCharFree); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewC); /* prototype */
  XS(XS_Bio__Emboss_ajStrFix); /* prototype */
  XS(XS_Bio__Emboss_ajStrFixI); /* prototype */
  XS(XS_Bio__Emboss_ajStrFixTestI); /* prototype */
  XS(XS_Bio__Emboss_ajStrStr); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenCount); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenCountR); /* prototype */
#else
  XS(XS_Bio__Emboss_ajCharFree); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewC); /* prototype */
  XS(XS_Bio__Emboss_ajStrFix); /* prototype */
  XS(XS_Bio__Emboss_ajStrFixI); /* prototype */
  XS(XS_Bio__Emboss_ajStrFixTestI); /* prototype */
  XS(XS_Bio__Emboss_ajStrStr); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenCount); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenCountR); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajCharNew); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewL); /* prototype */
  XS(XS_Bio__Emboss_ajCharNewLS); /* prototype */
  XS(XS_Bio__Emboss_ajCharPos); /* prototype */
  XS(XS_Bio__Emboss_ajCharToLower); /* prototype */
  XS(XS_Bio__Emboss_ajCharToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajStrApp); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppK); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppKI); /* prototype */
  XS(XS_Bio__Emboss_ajStrAppSub); /* prototype */
  XS(XS_Bio__Emboss_ajStrAss); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssC); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssCI); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssCL); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssI); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssL); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssS); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssSub); /* prototype */
  XS(XS_Bio__Emboss_ajStrAssSubC); /* prototype */
  XS(XS_Bio__Emboss_ajStrBlock); /* prototype */
  XS(XS_Bio__Emboss_ajStrBool); /* prototype */
  XS(XS_Bio__Emboss_ajStrChar); /* prototype */
  XS(XS_Bio__Emboss_ajStrCheck); /* prototype */
  XS(XS_Bio__Emboss_ajStrChomp); /* prototype */
  XS(XS_Bio__Emboss_ajStrChompC); /* prototype */
  XS(XS_Bio__Emboss_ajStrChompEnd); /* prototype */
  XS(XS_Bio__Emboss_ajStrChop); /* prototype */
  XS(XS_Bio__Emboss_ajStrClean); /* prototype */
  XS(XS_Bio__Emboss_ajStrCleanWhite); /* prototype */
  XS(XS_Bio__Emboss_ajStrClear); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpCaseCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmp); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpO); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpWild); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpWildC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCmpWildCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrConvert); /* prototype */
  XS(XS_Bio__Emboss_ajStrConvertCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCopy); /* prototype */
  XS(XS_Bio__Emboss_ajStrCopyC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCountC); /* prototype */
  XS(XS_Bio__Emboss_ajStrCountK); /* prototype */
  XS(XS_Bio__Emboss_ajStrCut); /* prototype */
  XS(XS_Bio__Emboss_ajStrDegap); /* prototype */
  XS(XS_Bio__Emboss_ajStrDel); /* prototype */
  XS(XS_Bio__Emboss_ajStrDelim); /* prototype */
  XS(XS_Bio__Emboss_ajStrDelReuse); /* prototype */
  XS(XS_Bio__Emboss_ajStrDup); /* prototype */
  XS(XS_Bio__Emboss_ajStrExit); /* prototype */
  XS(XS_Bio__Emboss_ajStrFind); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindC); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrFindCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrFill); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromBool); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromDouble); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromDoubleE); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromFloat); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromInt); /* prototype */
  XS(XS_Bio__Emboss_ajStrFromLong); /* prototype */
  XS(XS_Bio__Emboss_ajStrInsert); /* prototype */
  XS(XS_Bio__Emboss_ajStrInsertC); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsAlnum); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsAlpha); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsBool); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsDouble); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsFloat); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsHex); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsInt); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsLong); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsSpace); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsWild); /* prototype */
  XS(XS_Bio__Emboss_ajStrIsWord); /* prototype */
  XS(XS_Bio__Emboss_ajStrIter); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterBack); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterBackNext); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterFree); /* prototype */
  XS(XS_Bio__Emboss_ajStrIterNext); /* prototype */
  XS(XS_Bio__Emboss_ajStrJoin); /* prototype */
  XS(XS_Bio__Emboss_ajStrJoinC); /* prototype */
  XS(XS_Bio__Emboss_ajStrLen); /* prototype */
  XS(XS_Bio__Emboss_ajStrMask); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatch); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchCaseCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWild); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWildC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWildCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWildCO); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWord); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWordC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMatchWordCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrMod); /* prototype */
  XS(XS_Bio__Emboss_ajStrModL); /* prototype */
  XS(XS_Bio__Emboss_ajStrNCmpC); /* prototype */
  XS(XS_Bio__Emboss_ajStrNCmpCaseCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrNCmpO); /* prototype */
  XS(XS_Bio__Emboss_ajStrNew); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewC); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewCIL); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewCL); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewL); /* prototype */
  XS(XS_Bio__Emboss_ajStrNewS); /* prototype */
  XS(XS_Bio__Emboss_ajStrPos); /* prototype */
  XS(XS_Bio__Emboss_ajStrPosI); /* prototype */
  XS(XS_Bio__Emboss_ajStrPosII); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefix); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixC); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCase); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCaseC); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCaseCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCaseCO); /* prototype */
  XS(XS_Bio__Emboss_ajStrPrefixCO); /* prototype */
  XS(XS_Bio__Emboss_ajStrQuote); /* prototype */
  XS(XS_Bio__Emboss_ajStrQuoteStrip); /* prototype */
  XS(XS_Bio__Emboss_ajStrRandom); /* prototype */
  XS(XS_Bio__Emboss_ajStrReplace); /* prototype */
  XS(XS_Bio__Emboss_ajStrReplaceC); /* prototype */
  XS(XS_Bio__Emboss_ajStrReplaceK); /* prototype */
  XS(XS_Bio__Emboss_ajStrRef); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveHtml); /* prototype */
  XS(XS_Bio__Emboss_ajStrRemoveNewline); /* prototype */
  XS(XS_Bio__Emboss_ajStrRev); /* prototype */
  XS(XS_Bio__Emboss_ajStrRFindC); /* prototype */
  XS(XS_Bio__Emboss_ajStrRoom); /* prototype */
  XS(XS_Bio__Emboss_ajStrSet); /* prototype */
  XS(XS_Bio__Emboss_ajStrSetC); /* prototype */
  XS(XS_Bio__Emboss_ajStrSize); /* prototype */
  XS(XS_Bio__Emboss_ajStrStat); /* prototype */
  XS(XS_Bio__Emboss_ajStrSub); /* prototype */
  XS(XS_Bio__Emboss_ajStrSubstitute); /* prototype */
  XS(XS_Bio__Emboss_ajStrSubstituteCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrSubstituteKK); /* prototype */
  XS(XS_Bio__Emboss_ajStrSuffix); /* prototype */
  XS(XS_Bio__Emboss_ajStrSuffixC); /* prototype */
  XS(XS_Bio__Emboss_ajStrSuffixCC); /* prototype */
  XS(XS_Bio__Emboss_ajStrSuffixCO); /* prototype */
  XS(XS_Bio__Emboss_ajStrToBool); /* prototype */
  XS(XS_Bio__Emboss_ajStrToDouble); /* prototype */
  XS(XS_Bio__Emboss_ajStrToFloat); /* prototype */
  XS(XS_Bio__Emboss_ajStrToHex); /* prototype */
  XS(XS_Bio__Emboss_ajStrToInt); /* prototype */
  XS(XS_Bio__Emboss_ajStrTok); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokC); /* prototype */
  XS(XS_Bio__Emboss_ajStrToken); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenAss); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenClear); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenInit); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenReset); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenRest); /* prototype */
  XS(XS_Bio__Emboss_ajStrTokenTrace); /* prototype */
  XS(XS_Bio__Emboss_ajStrToLong); /* prototype */
  XS(XS_Bio__Emboss_ajStrToLower); /* prototype */
  XS(XS_Bio__Emboss_ajStrToUpper); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrace); /* prototype */
  XS(XS_Bio__Emboss_ajStrTraceChars); /* prototype */
  XS(XS_Bio__Emboss_ajStrTraceT); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrim); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrimC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTrimEndC); /* prototype */
  XS(XS_Bio__Emboss_ajStrTruncate); /* prototype */
  XS(XS_Bio__Emboss_ajStrWhole); /* prototype */
  XS(XS_Bio__Emboss_ajStrWildPrefix); /* prototype */
  XS(XS_Bio__Emboss_ajStrWrap); /* prototype */
  XS(XS_Bio__Emboss_ajStrWrapLeft); /* prototype */
  XS(XS_Bio__Emboss_ajStrYN); /* prototype */
  XS(XS_Bio__Emboss_ajTrnDel); /* prototype */
  XS(XS_Bio__Emboss_ajTrnNew); /* prototype */
  XS(XS_Bio__Emboss_ajTrnNewI); /* prototype */
  XS(XS_Bio__Emboss_ajTrnNewC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnReadFile); /* prototype */
  XS(XS_Bio__Emboss_ajTrnNewPep); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCodon); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevCodon); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCodonC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevCodonC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCodonK); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevCodonK); /* prototype */
  XS(XS_Bio__Emboss_ajTrnC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnAltRevC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStr); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevStr); /* prototype */
  XS(XS_Bio__Emboss_ajTrnAltRevStr); /* prototype */
  XS(XS_Bio__Emboss_ajTrnSeq); /* prototype */
  XS(XS_Bio__Emboss_ajTrnRevSeq); /* prototype */
  XS(XS_Bio__Emboss_ajTrnAltRevSeq); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCFrame); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStrFrame); /* prototype */
  XS(XS_Bio__Emboss_ajTrnSeqFrame); /* prototype */
  XS(XS_Bio__Emboss_ajTrnSeqFramePep); /* prototype */
  XS(XS_Bio__Emboss_ajTrnCDangle); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStrDangle); /* prototype */
  XS(XS_Bio__Emboss_ajTrnGetTitle); /* prototype */
  XS(XS_Bio__Emboss_ajTrnGetFileName); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStartStop); /* prototype */
  XS(XS_Bio__Emboss_ajTrnStartStopC); /* prototype */
  XS(XS_Bio__Emboss_ajTrnSeqOrig); /* prototype */
  XS(XS_Bio__Emboss_ajExit); /* prototype */
  XS(XS_Bio__Emboss_ajExitBad); /* prototype */
  XS(XS_Bio__Emboss_ajLogInfo); /* prototype */
  XS(XS_Bio__Emboss_ajUtilBigendian); /* prototype */
  XS(XS_Bio__Emboss_ajUtilCatch); /* prototype */
  XS(XS_Bio__Emboss_ajUtilRev2); /* prototype */
  XS(XS_Bio__Emboss_ajUtilRev4); /* prototype */
  XS(XS_Bio__Emboss_ajUtilRev8); /* prototype */
  XS(XS_Bio__Emboss_ajUtilUid); /* prototype */
#ifdef HAVE_EMBOSS_2_9_0
#else
  XS(XS_Bio__Emboss_ajXyzPdbtospNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbtospDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbtospRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbtospReadC); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbtospReadAll); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbtospBinSearch); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSortPdbtospPdb); /* prototype */
  XS(XS_Bio__Emboss_ajXyzAtomNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzAtomDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzInContact); /* prototype */
  XS(XS_Bio__Emboss_ajXyzAtomDistance); /* prototype */
  XS(XS_Bio__Emboss_ajXyzChainNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzChainDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbWriteAll); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbWriteDomain); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbChain); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbAtomIndexI); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbAtomIndexC); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbAtomIndexICA); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbAtomIndexCCA); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbToSp); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPdbToAcc); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCpdbRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCpdbReadFirstModel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCpdbReadOld); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCpdbWriteAll); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCpdbWriteDomain); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopReadC); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopReadAll); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopWrite); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopToPdb); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopToSp); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopToAcc); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopToScophit); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopCompId); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopCopy); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopclaNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopclaDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopclaRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopclaReadC); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopdesNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopdesDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopdesRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopdesReadC); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitsToHitlist); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitsOverlap); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitsOverlapAcc); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitCopy); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitListCopy); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitToHit); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitCheckTarget); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitTarget); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitTarget2); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitTargetLowPriority); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitMergeInsertThis); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitMergeInsertOther); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitMerge); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitCompSpr); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitCompStart); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitCompFold); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitCompSfam); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitCompFam); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScophitCompAcc); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitsOverlap); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCompScore); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCompScoreInv); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCompId); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistReadNode); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistReadFam); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistReadSfam); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistReadFold); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistWrite); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistToScophits); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistClassify); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistPriorityHigh); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistPriorityLow); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistToThreeScophits); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitlistsWriteFasta); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbSeqresChain); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbSeqresDomain); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbAtomChain); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbAtomDomain); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbHeterogen); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbText); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbHeader); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbHeaderScop); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbTitle); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbCompnd); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbSource); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbEmptyRemark); /* prototype */
  XS(XS_Bio__Emboss_ajXyzPrintPdbResolution); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopalgRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopalgWrite); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopalgWriteClustal); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopalgWriteClustal2); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopalgNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopalgDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScopalgGetseqs); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCmapNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCmapDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCmapRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCmapReadC); /* prototype */
  XS(XS_Bio__Emboss_ajXyzCmapReadI); /* prototype */
  XS(XS_Bio__Emboss_ajXyzVdwRad); /* prototype */
  XS(XS_Bio__Emboss_ajXyzVdwallNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzVdwallDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzVdwallRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzVdwresNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzVdwresDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScorealgNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzScorealgDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSigdatNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSigposNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSigdatDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSigposDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitidxNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitidxDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHitidxBinSearch); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSignatureNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSignatureDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSignatureRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSignatureWrite); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSignatureCompile); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSignatureAlignSeq); /* prototype */
  XS(XS_Bio__Emboss_ajXyzSignatureAlignSeqall); /* prototype */
#ifdef HAVE_EMBOSS_2_6_0
  XS(XS_Bio__Emboss_ajXyzSignatureHitsWrite); /* prototype */
#else
  XS(XS_Bio__Emboss_ajXyzSignatureHitsWrite); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajXyzSignatureAlignWrite); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHetentNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHetentDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHetNew); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHetDel); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHetRawRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHetRead); /* prototype */
  XS(XS_Bio__Emboss_ajXyzHetWrite); /* prototype */
#endif
  XS(XS_Bio__Emboss_embGrpCompareTwoGnodes); /* prototype */
  XS(XS_Bio__Emboss_embGrpGetProgGroups); /* prototype */
  XS(XS_Bio__Emboss_embGrpGroupsListDel); /* prototype */
  XS(XS_Bio__Emboss_embGrpKeySearchProgs); /* prototype */
  XS(XS_Bio__Emboss_embGrpKeySearchSeeAlso); /* prototype */
  XS(XS_Bio__Emboss_embGrpMakeNewGnode); /* prototype */
  XS(XS_Bio__Emboss_embGrpMakeNewPnode); /* prototype */
  XS(XS_Bio__Emboss_embGrpOutputGroupsList); /* prototype */
  XS(XS_Bio__Emboss_embGrpOutputProgsList); /* prototype */
  XS(XS_Bio__Emboss_embGrpSortGroupsList); /* prototype */
  XS(XS_Bio__Emboss_embGrpMakeUnique); /* prototype */
#ifndef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajGraphBox); /* prototype */
  XS(XS_Bio__Emboss_ajGraphBoxFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphCheckColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphCircle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphClose); /* prototype */
  XS(XS_Bio__Emboss_ajGraphCloseWin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphColourBack); /* prototype */
  XS(XS_Bio__Emboss_ajGraphColourFore); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataDel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataObjAddLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataObjAddRect); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataObjAddText); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataxySetMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataxyMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataxySetMaxima); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataxySetTypeC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDia); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDiaFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDots); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDumpDevices); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetCharSize); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetOut); /* prototype */
  XS(XS_Bio__Emboss_ajGraphHoriBars); /* prototype */
  XS(XS_Bio__Emboss_ajGraphInfo); /* prototype */
  XS(XS_Bio__Emboss_ajGraphInitSeq); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLabel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLabelYRight); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLines); /* prototype */
  XS(XS_Bio__Emboss_ajGraphNew); /* prototype */
  XS(XS_Bio__Emboss_ajGraphNewPage); /* prototype */
  XS(XS_Bio__Emboss_ajGraphObjAddLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphObjAddRect); /* prototype */
  XS(XS_Bio__Emboss_ajGraphObjAddText); /* prototype */
  XS(XS_Bio__Emboss_ajGraphObjDel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataObjDel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphOpen); /* prototype */
  XS(XS_Bio__Emboss_ajGraphOpenPlot); /* prototype */
  XS(XS_Bio__Emboss_ajGraphOpenWin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlenv); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPoly); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPolyFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPrintType); /* prototype */
  XS(XS_Bio__Emboss_ajGraphRect); /* prototype */
  XS(XS_Bio__Emboss_ajGraphRectFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSet); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetDevice); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetCharSize); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetBackBlack); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetBackWhite); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetPenWidth); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetFillPat); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetFore); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetLineStyle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetMulti); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetName); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetOri); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSymbols); /* prototype */
  XS(XS_Bio__Emboss_ajGraphText); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextEnd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextMid); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextStart); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTrace); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTraceInt); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTri); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTriFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphUnused); /* prototype */
  XS(XS_Bio__Emboss_ajGraphVertBars); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyAddDataCalcPtr); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyAddDataPtrPtr); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyAddGraph); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyReplaceGraph); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataNew); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataNewI); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataSetSubtitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataSetSubtitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataSetTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataSetTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataSetXtitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataSetXtitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataSetYtitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDataSetYtitleC); /* prototype */
#ifdef HAVE_EMBOSS_2_8_0
  XS(XS_Bio__Emboss_ajGraphxyDel); /* prototype */
#else
  XS(XS_Bio__Emboss_ajGraphxyDel); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajGraphxyDisplay); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyInitGraphCalcPtr); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyNewI); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyCheckMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySet); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetCirclePoints); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetFlag); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetGaps); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetJoinPoints); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetLineType); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetOut); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetOutC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetOverLap); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetSubtitleDo); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetTitleDo); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXBottom); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXLabelTop); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXTick); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXTop); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXEnd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXGrid); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXInvTicks); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXLabel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXRangeII); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXStart); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYLabelLeft); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYLeft); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYRight); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYTick); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYEnd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYGrid); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYInvTicks); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYLabel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYRangeII); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYStart); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySubtitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySubtitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyXtitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyXtitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyYtitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyYtitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPartCircle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDrawTextOnCurve); /* prototype */
  XS(XS_Bio__Emboss_ajGraphRectangleOnCurve); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextLength); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextHeight); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDistPts); /* prototype */
  XS(XS_Bio__Emboss_ajGraphFitTextOnLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetDefCharSize); /* prototype */
  XS(XS_Bio__Emboss_ajGraphFillRectangleOnCurve); /* prototype */
#endif
#ifdef HAVE_EMBOSS_2_9_0
  XS(XS_Bio__Emboss_ajGraphBox); /* prototype */
  XS(XS_Bio__Emboss_ajGraphBoxFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphCheckColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphCircle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphClose); /* prototype */
  XS(XS_Bio__Emboss_ajGraphCloseWin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphColourBack); /* prototype */
  XS(XS_Bio__Emboss_ajGraphColourFore); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataAddLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataAddRect); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataAddText); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphArrayMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetMaxima); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetTypeC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataTrace); /* prototype */
  XS(XS_Bio__Emboss_ajGraphClear); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDia); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDiaFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDots); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDumpDevices); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetCharSize); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetOut); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetSubTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetSubTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetXTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetXTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetYTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphGetYTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphHoriBars); /* prototype */
  XS(XS_Bio__Emboss_ajGraphInfo); /* prototype */
  XS(XS_Bio__Emboss_ajGraphInitSeq); /* prototype */
  XS(XS_Bio__Emboss_ajGraphIsData); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLabel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLabelYRight); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphLines); /* prototype */
  XS(XS_Bio__Emboss_ajGraphNew); /* prototype */
  XS(XS_Bio__Emboss_ajGraphNewPage); /* prototype */
  XS(XS_Bio__Emboss_ajGraphAddLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphAddRect); /* prototype */
  XS(XS_Bio__Emboss_ajGraphAddText); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataDel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphOpen); /* prototype */
  XS(XS_Bio__Emboss_ajGraphOpenPlot); /* prototype */
  XS(XS_Bio__Emboss_ajGraphOpenWin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlenv); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPoly); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPolyFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPrintType); /* prototype */
  XS(XS_Bio__Emboss_ajGraphRect); /* prototype */
  XS(XS_Bio__Emboss_ajGraphRectFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSet); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetDevice); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetBackBlack); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetBackWhite); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetPenWidth); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetFillPat); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetFore); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetLineStyle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetMulti); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetName); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetOri); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSymbols); /* prototype */
  XS(XS_Bio__Emboss_ajGraphText); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextEnd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextMid); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextStart); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTrace); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTraceInt); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTri); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTriFill); /* prototype */
  XS(XS_Bio__Emboss_ajGraphUnused); /* prototype */
  XS(XS_Bio__Emboss_ajGraphVertBars); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataCalcXY); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetXY); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataAdd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDataReplace); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataNew); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataNewI); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetSubTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetSubTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetXTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetXTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetYTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetYTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyDisplay); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyNewI); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxyCheckMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySet); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetCirclePoints); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetColour); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetFlag); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetJoinPoints); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPlpDataSetLineType); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetMaxMin); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetOut); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetOutC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetOverLap); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetSubTitleDo); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetTitleDo); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXBottom); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXLabelTop); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXTick); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXTop); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXEnd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXGrid); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXInvTicks); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXLabel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXRangeII); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetXStart); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYLabelLeft); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYLeft); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYRight); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYTick); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYEnd); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYGrid); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYInvTicks); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYLabel); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYRangeII); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetYStart); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetSubTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetSubTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetXTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetXTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetYTitle); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetYTitleC); /* prototype */
  XS(XS_Bio__Emboss_ajGraphxySetGaps); /* prototype */
  XS(XS_Bio__Emboss_ajGraphPartCircle); /* prototype */
#if 0
  XS(XS_Bio__Emboss_ajComputeCoord); /* prototype */
#endif
  XS(XS_Bio__Emboss_ajGraphDrawTextOnCurve); /* prototype */
  XS(XS_Bio__Emboss_ajGraphRectangleOnCurve); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextLength); /* prototype */
  XS(XS_Bio__Emboss_ajGraphTextHeight); /* prototype */
  XS(XS_Bio__Emboss_ajGraphDistPts); /* prototype */
  XS(XS_Bio__Emboss_ajGraphFitTextOnLine); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetCharSize); /* prototype */
  XS(XS_Bio__Emboss_ajGraphSetDefCharSize); /* prototype */
  XS(XS_Bio__Emboss_ajGraphFillRectangleOnCurve); /* prototype */
#endif
